==> haskell-monad-journal-0.8.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-KFy1VxzClXlJKU3bZea8f
key: monad-journal-0.8.1-KFy1VxzClXlJKU3bZea8f
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: 928608347ed77512d84aeba5eaa30d4e
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-KFy1VxzClXlJKU3bZea8f
depends:
    base-4.12.0.0 monad-control-1.0.2.3-HrYPbjEu44jLedbHP7C2CP
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-AKjzOvjUCFd4YE2ZLG0MGC
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.1
id: monad-journal-0.8.1-5LPVutlXEJdKGVlT1sd1Wo
key: monad-journal-0.8.1-5LPVutlXEJdKGVlT1sd1Wo
license: BSD-3-Clause
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
abi: ef06bd8fb91301836fb386bbf79f4db4
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-journal-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-journal-0.8.1
hs-libraries: HSmonad-journal-0.8.1-5LPVutlXEJdKGVlT1sd1Wo
depends:
    base-4.12.0.0 monad-control-1.0.2.3-JMF7teit9M6FKdrQm56I9R
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-or9mqY8NTvHJLsZFWJxI7
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
